searchData={"items":[{"type":"module","title":"LocalhostRun","doc":"Elixir client for localhost.run","ref":"LocalhostRun.html"},{"type":"module","title":"Usage - LocalhostRun","doc":"<!-- tabs-open -->","ref":"LocalhostRun.html#module-usage"},{"type":"module","title":"Via `GenServer` - LocalhostRun","doc":"```elixir\n{:ok, pid} = LocalhostRun.start_link(internal_port: 4000)\n```","ref":"LocalhostRun.html#module-via-genserver"},{"type":"module","title":"Via `Supervisor` - LocalhostRun","doc":"```elixir\nchildren = [\n  {LocalhostRun, [internal_port: 4000]}\n]\nopts = [strategy: :one_for_one, name: MyApp.Supervisor]\nSupervisor.start_link(children, opts)\n```","ref":"LocalhostRun.html#module-via-supervisor"},{"type":"module","title":"Direct - LocalhostRun","doc":"```elixir\n{:ok, {conn_ref, channel_id}} = LocalhostRun.connect(internal_port: 4000)\n\nreceive do\n  {:ssh_cm, ^conn_ref, {:data, ^channel_id, 0, message}} ->\n    case JSON.decode!(message) do\n      %{\"event\" => \"tcpip-forward\", \"address\" => host} ->\n        Logger.info(\"Tunnel established to #{host}\")\n        {:ok, host}\n\n      %{\"event\" => \"authn\", \"message\" => message} ->\n        Logger.info(\"Tunnel authentication successful: #{message}\")\n        :ok\n\n      %{\"message\" => message} ->\n        Logger.debug(\"Received message from SSH channel on STDOUT: #{inspect(message)}\")\n    end\nend\n```\n\n<!-- tabs-close -->","ref":"LocalhostRun.html#module-direct"},{"type":"module","title":"Login to localhost.run - LocalhostRun","doc":"If you want custom domain names or longer lasting tunnels, you need to login\nto localhost.run.\n\nSee: https://localhost.run/docs/custom-domains\n\nTo do so, you have the following options:\n\n<!-- tabs-open -->","ref":"LocalhostRun.html#module-login-to-localhost-run"},{"type":"module","title":"Use SSH Agent - LocalhostRun","doc":"To use your SSH agent, ensure that it is running and that you have added your\nSSH key to it. You can verify that your SSH agent is running by running the\nfollowing command:\n\n```bash\nssh-add -l\n```\nIf you see a list of keys, your SSH agent is running. If not, you can start it by running:\n\n```bash\neval \"$(ssh-agent -s)\"\n```\n\nThen, add your SSH key to the agent:\n\n```bash\nssh-add ~/.ssh/id_rsa\n```\n\nAfterwards you can use the `LocalhostRun` module with the `:ssh_options` option\nto specify the SSH agent:\n\n```elixir\n{:ok, pid} = LocalhostRun.start_link(internal_port: 4000, ssh_options: [\n  user: \"your_username\",\n  key_cb: {:ssh_agent, []}\n])\n```\n\nCheck the [`ssh_agent`] documentation for more information.","ref":"LocalhostRun.html#module-use-ssh-agent"},{"type":"module","title":"Use SSH Key - LocalhostRun","doc":"If you want to use a specific SSH key, you can specify to use the `key_cb`\n`ssh_file` in the `:ssh_options` option:\n\n```elixir\n{:ok, pid} = LocalhostRun.start_link(internal_port: 4000, ssh_options: [\n  user: \"your_username\",\n  key_cb: {:ssh_file, []}\n])\n```\n\nCheck the `ssh_file` documentation for more information.\n\n<!-- tabs-close -->","ref":"LocalhostRun.html#module-use-ssh-key"},{"type":"module","title":"Logger Metadata - LocalhostRun","doc":"The `LocalhostRun` module automatically sets the following metadata for the\n`Logger` module:\n\n- `ssh_host` - The SSH host to connect to.\n- `ssh_port` - The SSH port to connect to.\n- `external_host` - The external host to use for the tunnel.\n- `internal_port` - The internal port to forward.","ref":"LocalhostRun.html#module-logger-metadata"},{"type":"function","title":"LocalhostRun.connect/1","doc":"Connects to the SSH server and sets up the tunnel.","ref":"LocalhostRun.html#connect/1"},{"type":"function","title":"LocalhostRun.get_exposed_host/1","doc":"Returns the exposed host for the tunnel.\nThis function blocks until the tunnel is established and the host is available.","ref":"LocalhostRun.html#get_exposed_host/1"},{"type":"type","title":"LocalhostRun.opts/0","doc":"Options for the `LocalhostRun` GenServer.\n\n- `:name` - The name of the GenServer process. Default is `LocalhostRun`.\n- `:ssh_host` - The SSH host to connect to. Default is `localhost.run`.\n- `:ssh_port` - The SSH port to connect to. Default is `22`.\n- `:external_host` - The external host to use for the tunnel. Default is a random host.\n- `:ssh_options` - Additional SSH options. Default is an empty list.\n- `:connect_timeout` - The timeout for the SSH connection. Default is `10` seconds.\n- `:internal_port` - The internal port to forward. This is required and should be provided.","ref":"LocalhostRun.html#t:opts/0"},{"type":"function","title":"LocalhostRun.start_link/1","doc":"Starts the `LocalhostRun` GenServer.\n\nIt connects to the SSH server and sets up the tunnel.\n\nThe `:internal_port` option is required and should be provided.","ref":"LocalhostRun.html#start_link/1"},{"type":"extras","title":"LocalhostRun","doc":"# LocalhostRun\n\n[![Main Branch](https://github.com/erlef/localhost-run/actions/workflows/branch_main.yml/badge.svg?branch=main)](https://github.com/erlef/localhost-run/actions/workflows/branch_main.yml)\n[![Module Version](https://img.shields.io/hexpm/v/localhost_run.svg)](https://hex.pm/packages/localhost_run)\n[![Total Download](https://img.shields.io/hexpm/dt/localhost_run.svg)](https://hex.pm/packages/localhost_run)\n[![License](https://img.shields.io/hexpm/l/localhost_run.svg)](https://github.com/erlef/localhost-run/blob/main/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/erlef/localhost-run.svg)](https://github.com/erlef/localhost-run/commits/master)\n[![Coverage Status](https://coveralls.io/repos/github/erlef/localhost-run/badge.svg?branch=main)](https://coveralls.io/github/erlef/localhost-run?branch=main)\n\nA small Elixir client for [localhost.run](https://localhost.run), which lets you\nexpose local ports to the internet via SSH tunnels.\n\nThis can be useful for development, testing webhooks, or sharing a local server\nwith someone. It supports both unauthenticated and authenticated connections\nusing SSH keys or your local SSH agent.","ref":"readme.html"},{"type":"extras","title":"Installation - LocalhostRun","doc":"Add to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:localhost_run, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - LocalhostRun","doc":"You can use this module in different ways depending on your needs.","ref":"readme.html#basic-usage"},{"type":"extras","title":"Start with `GenServer` - LocalhostRun","doc":"```elixir\n{:ok, pid} = LocalhostRun.start_link(internal_port: 4000)\n```","ref":"readme.html#start-with-genserver"},{"type":"extras","title":"As a supervised process - LocalhostRun","doc":"```elixir\nchildren = [\n  {LocalhostRun, [internal_port: 4000]}\n]\n\nopts = [strategy: :one_for_one, name: MyApp.Supervisor]\nSupervisor.start_link(children, opts)\n```","ref":"readme.html#as-a-supervised-process"},{"type":"extras","title":"Manual connection - LocalhostRun","doc":"```elixir\n{:ok, {conn_ref, channel_id}} = LocalhostRun.connect(internal_port: 4000)\n\nreceive do\n  {:ssh_cm, ^conn_ref, {:data, ^channel_id, 0, message}} ->\n    case JSON.decode!(message) do\n      %{\"event\" => \"tcpip-forward\", \"address\" => host} ->\n        Logger.info(\"Tunnel established to #{host}\")\n\n      %{\"event\" => \"authn\", \"message\" => msg} ->\n        Logger.info(\"Authentication successful: #{msg}\")\n\n      %{\"message\" => msg} ->\n        Logger.debug(\"Received: #{inspect(msg)}\")\n    end\nend\n```","ref":"readme.html#manual-connection"},{"type":"extras","title":"Authentication - LocalhostRun","doc":"To use features like custom domains or longer tunnel timeouts, you’ll need to\nauthenticate with localhost.run.\n\nSee their [docs](https://localhost.run/docs/custom-domains) for details.\n\nYou have two options:","ref":"readme.html#authentication"},{"type":"extras","title":"SSH agent - LocalhostRun","doc":"Make sure your SSH agent is running and your key is added:\n\n```bash\neval \"$(ssh-agent -s)\"\nssh-add ~/.ssh/id_rsa\n```\n\nThen pass the agent to `LocalhostRun`:\n\n```elixir\n{:ok, pid} = LocalhostRun.start_link(internal_port: 4000, ssh_options: [\n  user: \"your_username\",\n  key_cb: {:ssh_agent, []}\n])\n```","ref":"readme.html#ssh-agent"},{"type":"extras","title":"SSH key file - LocalhostRun","doc":"Alternatively, you can specify a key file:\n\n```elixir\n{:ok, pid} = LocalhostRun.start_link(internal_port: 4000, ssh_options: [\n  user: \"your_username\",\n  key_cb: {:ssh_file, []}\n])\n```","ref":"readme.html#ssh-key-file"},{"type":"extras","title":"Getting the tunnel address - LocalhostRun","doc":"If you need to get the public address of the tunnel:\n\n```elixir\n{:ok, host} = LocalhostRun.get_exposed_host()\nIO.puts(\"Tunnel is available at #{host}\")\n```","ref":"readme.html#getting-the-tunnel-address"},{"type":"extras","title":"Logging - LocalhostRun","doc":"The module sets some helpful metadata in your logs:\n\n* `:ssh_host`\n* `:ssh_port`\n* `:external_host`\n* `:internal_port`\n\nThis can help with debugging or tracing tunnel usage.","ref":"readme.html#logging"},{"type":"extras","title":"License - LocalhostRun","doc":"Copyright 2025 Jonatan Männchen\n    Copyright 2025 Erlang Ecosystem Foundation\n\n    Licensed under the Apache License, Version 2.0 (the \"License\");\n    you may not use this file except in compliance with the License.\n    You may obtain a copy of the License at\n\n        http://www.apache.org/licenses/LICENSE-2.0\n\n    Unless required by applicable law or agreed to in writing, software\n    distributed under the License is distributed on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n    See the License for the specific language governing permissions and\n    limitations under the License.","ref":"readme.html#license"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.3"}}